summaryrefslogtreecommitdiffstats
path: root/tools/designer/plugins/cppeditor/yyreg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tools/designer/plugins/cppeditor/yyreg.cpp')
-rw-r--r--tools/designer/plugins/cppeditor/yyreg.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/tools/designer/plugins/cppeditor/yyreg.cpp b/tools/designer/plugins/cppeditor/yyreg.cpp
index 144c99f..0648e36 100644
--- a/tools/designer/plugins/cppeditor/yyreg.cpp
+++ b/tools/designer/plugins/cppeditor/yyreg.cpp
@@ -71,7 +71,7 @@ enum { Tok_Boi, Tok_Ampersand, Tok_Aster, Tok_LeftParen, Tok_RightParen,
/*
The following variables store the lexical analyzer state. The best way
to understand them is to implement a function myGetToken() that calls
- getToken(), to add some qDebug() statements in there and then to
+ getToken(), to add some tqDebug() statements in there and then to
#define getToken() myGetToken().
*/
static QString *yyIn; // the input stream
@@ -143,7 +143,7 @@ static void stopTokenizer()
*/
static int getToken()
{
// why "+ 2"? try putting some qDebug()'s and see
yyPos = yyCurPos + 2;
for ( ;; ) {
@@ -177,7 +177,7 @@ static int getToken()
around with the tokenizer state to effectively
ignore the comment. Beware of off-by-one and
off-by-two bugs when you modify this code by adding
- qDebug()'s here and there.
+ tqDebug()'s here and there.
*/
if ( yyCurPos >= 0 ) {
int lineStart = yyIn->findRev( QChar('\n'), yyCurPos ) + 1;
@@ -143,7 +143,7 @@ static void stopTokenizer()
static int getToken()
{
- // why "+ 2"? try putting some qDebug()'s and see
+ // why "+ 2"? try putting some tqDebug()'s and see
yyPos = yyCurPos + 2;
for ( ;; ) {